function dy = dglferry(t,y,flag,alpha,parameter)
% Loesung eines Optimalsteuerungsproblems
% am Beispiel des Zermelo Problems (Ferryman)
% In diesem File werden die Differentialgleichungen fuer den Integrationsschritt
% definiert.
% -------------------------------------------------------------------------------
% Eingabe - Parameter:
% t : unabhaengige Variable (Zeit)
% y : abhaengige Variable
% flag : wird in diesem Fall nicht benutzt. Mittels "flag" kann die Ausgabe der 
%        Funktion an den Integrator gesteuert werden.
% alpha : Parameter: Steuerung, diese ist zwischen zwei Knoten konstant.
% parameter(1): Endzeit tf
% parameter(2): Eigengeschwindigkeit des Bootes W
% -------------------------------------------------------------------------------
% Rueckgabe-Parameter:
% dy : die rechte Seite der Differentialgleichung y' = f(t,y)
% -------------------------------------------------------------------------------
%
% 9.1.1999   Helge Baumann
%
s0 = 1;
tf = parameter(1);
W = parameter(2);

dy = zeros(2,1);
dy(1) = tf * W * cos(alpha);
dy(2) = tf *(W * sin(alpha) + s0 * (1- y(1)^2) );
return

